@@ -31,28 +31,22 @@ __END__
 
 =head1 NAME
 
-Path::Dispatcher::Rule::Regex - predicate is a regular expression
+Path::Dispatcher::Rule::Eq - predicate is a string equality
 
 =head1 SYNOPSIS
 
-    my $rule = Path::Dispatcher::Rule::Regex->new(
-        regex => qr{^/comment(s?)/(\d+)$},
-        block => sub { display_comment($2) },
+    my $rule = Path::Dispatcher::Rule::Eq->new(
+        string => 'comment',
+        block  => sub { display_comment($2) },
     );
 
 =head1 DESCRIPTION
 
-Rules of this class use a regular expression to match against the path.
+Rules of this class simply check whether the string is equal to the path.
 
 =head1 ATTRIBUTES
 
-=head2 regex
-
-The regular expression to match against the path. It works just as you'd expect!
-
-The results are the capture variables (C<$1>, C<$2>, etc) and when the
-resulting L<Path::Dispatcher::Match> is executed, the codeblock will see these
-values. C<$`>, C<$&>, and C<$'> are not (yet) restored.
+=head2 string
 
 =cut
 
